@@ -1,40 +1,56 @@
-#' Create a Forest Plot based on a Table
+#' Create a forest plot from an `rtable`
 #'
-#' Create a forest plot from any [rtables::rtable()] object that has a
-#' column with a single value and a column with 2 values.
+#' Given a [rtables::rtable()] object with at least one column with a single value and one column with 2
+#' values, converts table to a [ggplot2::ggplot()] object and generates an accompanying forest plot. The
+#' table and forest plot are printed side-by-side.
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
-#' @inheritParams grid::gTree
+#' @inheritParams rtable2gg
 #' @inheritParams argument_convention
-#' @param tbl (`rtable`)
-#' @param col_x (`integer`)\cr column index with estimator. By default tries to get this from
-#'   `tbl` attribute `col_x`, otherwise needs to be manually specified.
-#' @param col_ci (`integer`)\cr column index with confidence intervals. By default tries
-#'   to get this from `tbl` attribute `col_ci`, otherwise needs to be manually specified.
-#' @param vline (`number`)\cr x coordinate for vertical line, if `NULL` then the line is omitted.
-#' @param forest_header (`character`, length 2)\cr text displayed to the left and right of `vline`, respectively.
-#'   If `vline = NULL` then `forest_header` needs to be `NULL` too.
-#'   By default tries to get this from `tbl` attribute `forest_header`.
-#' @param xlim (`numeric`)\cr limits for x axis.
+#' @param tbl (`VTableTree`)\cr `rtables` table with at least one column with a single value and one column with 2
+#'   values.
+#' @param col_x (`integer(1)` or `NULL`)\cr column index with estimator. By default tries to get this from
+#'   `tbl` attribute `col_x`, otherwise needs to be manually specified. If `NULL`, points will be excluded
+#'   from forest plot.
+#' @param col_ci (`integer(1)` or `NULL`)\cr column index with confidence intervals. By default tries to get this from
+#'   `tbl` attribute `col_ci`, otherwise needs to be manually specified. If `NULL`, lines will be excluded
+#'   from forest plot.
+#' @param vline (`numeric(1)` or `NULL`)\cr x coordinate for vertical line, if `NULL` then the line is omitted.
+#' @param forest_header (`character(2)`)\cr text displayed to the left and right of `vline`, respectively.
+#'   If `vline = NULL` then `forest_header` is not printed. By default tries to get this from `tbl` attribute
+#'   `forest_header`. If `NULL`, defaults will be extracted from the table if possible, and set to
+#'   `"Comparison\nBetter"` and `"Treatment\nBetter"` if not.
+#' @param xlim (`numeric(2)`)\cr limits for x axis.
 #' @param logx (`flag`)\cr show the x-values on logarithm scale.
-#' @param x_at (`numeric`)\cr x-tick locations, if `NULL` they get automatically chosen.
-#' @param width_row_names (`unit`)\cr width for row names.
-#'   If `NULL` the widths get automatically calculated. See [grid::unit()].
-#' @param width_columns (`unit`)\cr widths for the table columns.
-#'   If `NULL` the widths get automatically calculated. See [grid::unit()].
-#' @param width_forest (`unit`)\cr width for the forest column.
-#'   If `NULL` the widths get automatically calculated. See [grid::unit()].
-#' @param col_symbol_size (`integer`)\cr column index from `tbl` containing data to be used
+#' @param x_at (`numeric`)\cr x-tick locations, if `NULL`, `x_at` is set to `vline` and both `xlim` values.
+#' @param width_row_names `r lifecycle::badge("deprecated")` Please use the `lbl_col_padding` argument instead.
+#' @param width_columns (`numeric`)\cr a vector of column widths. Each element's position in
+#'   `colwidths` corresponds to the column of `tbl` in the same position. If `NULL`, column widths are calculated
+#'   according to maximum number of characters per column.
+#' @param width_forest `r lifecycle::badge("deprecated")` Please use the `rel_width_forest` argument instead.
+#' @param rel_width_forest (`proportion`)\cr proportion of total width to allocate to the forest plot. Relative
+#'   width of table is then `1 - rel_width_forest`. If `as_list = TRUE`, this parameter is ignored.
+#' @param font_size (`numeric(1)`)\cr font size.
+#' @param col_symbol_size (`numeric` or `NULL`)\cr column index from `tbl` containing data to be used
 #'   to determine relative size for estimator plot symbol. Typically, the symbol size is proportional
 #'   to the sample size used to calculate the estimator. If `NULL`, the same symbol size is used for all subgroups.
 #'   By default tries to get this from `tbl` attribute `col_symbol_size`, otherwise needs to be manually specified.
 #' @param col (`character`)\cr color(s).
+#' @param ggtheme (`theme`)\cr a graphical theme as provided by `ggplot2` to control styling of the plot.
+#' @param as_list (`flag`)\cr whether the two `ggplot` objects should be returned as a list. If `TRUE`, a named list
+#'   with two elements, `table` and `plot`, will be returned. If `FALSE` (default) the table and forest plot are
+#'   printed side-by-side via [cowplot::plot_grid()].
+#' @param gp `r lifecycle::badge("deprecated")` `g_forest` is now generated as a `ggplot` object. This argument
+#'   is no longer used.
+#' @param draw `r lifecycle::badge("deprecated")` `g_forest` is now generated as a `ggplot` object. This argument
+#'   is no longer used.
+#' @param newpage `r lifecycle::badge("deprecated")` `g_forest` is now generated as a `ggplot` object. This argument
+#'   is no longer used.
 #'
-#' @return `gTree` object containing the forest plot and table.
+#' @return `ggplot` forest plot and table.
 #'
 #' @examples
-#' \donttest{
 #' library(dplyr)
 #' library(forcats)
 #' library(nestcolor)
@@ -61,22 +77,17 @@
 #'
 #' tbl <- basic_table() %>%
 #'   tabulate_rsp_subgroups(df)
-#' p <- g_forest(tbl, gp = grid::gpar(fontsize = 10))
-#'
-#' draw_grob(p)
+#' g_forest(tbl)
 #'
 #' # Odds ratio only table.
 #'
 #' tbl_or <- basic_table() %>%
 #'   tabulate_rsp_subgroups(df, vars = c("n_tot", "or", "ci"))
-#' tbl_or
-#' p <- g_forest(
+#' g_forest(
 #'   tbl_or,
 #'   forest_header = c("Comparison\nBetter", "Treatment\nBetter")
 #' )
 #'
-#' draw_grob(p)
-#'
 #' # Survival forest plot example.
 #' adtte <- tern_ex_adtte
 #' # Save variable labels before data processing steps.
@@ -112,6 +123,7 @@
 #' table_hr <- basic_table() %>%
 #'   tabulate_survival_subgroups(df, time_unit = adtte_f$AVALU[1])
 #' g_forest(table_hr)
+#'
 #' # Works with any `rtable`.
 #' tbl <- rtable(
 #'   header = c("E", "CI", "N"),
@@ -126,6 +138,7 @@
 #'   x_at = c(0.5, 1, 2),
 #'   col_symbol_size = 3
 #' )
+#'
 #' tbl <- rtable(
 #'   header = rheader(
 #'     rrow("", rcell("A", colspan = 2)),
@@ -143,7 +156,6 @@
 #'   vline = 1,
 #'   forest_header = c("Hello", "World")
 #' )
-#' }
 #'
 #' @export
 g_forest <- function(tbl,
@@ -154,121 +166,284 @@ g_forest <- function(tbl,
                      xlim = c(0.1, 10),
                      logx = TRUE,
                      x_at = c(0.1, 1, 10),
-                     width_row_names = NULL,
+                     width_row_names = lifecycle::deprecated(),
                      width_columns = NULL,
-                     width_forest = grid::unit(1, "null"),
+                     width_forest = lifecycle::deprecated(),
+                     lbl_col_padding = 0,
+                     rel_width_forest = 0.25,
+                     font_size = 12,
                      col_symbol_size = attr(tbl, "col_symbol_size"),
                      col = getOption("ggplot2.discrete.colour")[1],
-                     gp = NULL,
-                     draw = TRUE,
-                     newpage = TRUE) {
+                     ggtheme = NULL,
+                     as_list = FALSE,
+                     gp = lifecycle::deprecated(),
+                     draw = lifecycle::deprecated(),
+                     newpage = lifecycle::deprecated()) {
+  # Deprecated argument warnings
+  if (lifecycle::is_present(width_row_names)) {
+    lifecycle::deprecate_warn(
+      "0.9.3", "g_forest(width_row_names)", "g_forest(lbl_col_padding)",
+      details = "The width of the row label column can be adjusted via the `lbl_col_padding` parameter."
+    )
+  }
+  if (lifecycle::is_present(width_forest)) {
+    lifecycle::deprecate_warn(
+      "0.9.3", "g_forest(width_forest)", "g_forest(rel_width_forest)",
+      details = "Relative width of the forest plot (as a proportion) can be set via the `rel_width_forest` parameter."
+    )
+  }
+  if (lifecycle::is_present(gp)) {
+    lifecycle::deprecate_warn(
+      "0.9.3", "g_forest(gp)", "g_forest(ggtheme)",
+      details = paste(
+        "`g_forest` is now generated as a `ggplot` object.",
+        "Additional display settings should be supplied via the `ggtheme` parameter."
+      )
+    )
+  }
+  if (lifecycle::is_present(draw)) {
+    lifecycle::deprecate_warn(
+      "0.9.3", "g_forest(draw)",
+      details = "`g_forest` now generates `ggplot` objects. This parameter has no effect."
+    )
+  }
+  if (lifecycle::is_present(newpage)) {
+    lifecycle::deprecate_warn(
+      "0.9.3", "g_forest(newpage)",
+      details = "`g_forest` now generates `ggplot` objects. This parameter has no effect."
+    )
+  }
+
   checkmate::assert_class(tbl, "VTableTree")
+  checkmate::assert_number(col_x, lower = 0, upper = ncol(tbl), null.ok = TRUE)
+  checkmate::assert_number(col_ci, lower = 0, upper = ncol(tbl), null.ok = TRUE)
+  checkmate::assert_number(col_symbol_size, lower = 0, upper = ncol(tbl), null.ok = TRUE)
+  checkmate::assert_number(font_size, lower = 0)
+  checkmate::assert_character(col, null.ok = TRUE)
+  checkmate::assert_true(is.null(col) | length(col) == 1 | length(col) == nrow(tbl))
 
-  nr <- nrow(tbl)
-  nc <- ncol(tbl)
-  if (is.null(col)) {
-    col <- "blue"
-  }
+  # Extract info from table
+  mat <- matrix_form(tbl)
+  mat_strings <- formatters::mf_strings(mat)
+  nlines_hdr <- formatters::mf_nlheader(mat)
+  nrows_body <- nrow(mat_strings) - nlines_hdr
+  tbl_stats <- mat_strings[nlines_hdr, -1]
 
-  checkmate::assert_number(col_x, lower = 0, upper = nc, null.ok = FALSE)
-  checkmate::assert_number(col_ci, lower = 0, upper = nc, null.ok = FALSE)
-  checkmate::assert_number(col_symbol_size, lower = 0, upper = nc, null.ok = TRUE)
-  checkmate::assert_true(col_x > 0)
-  checkmate::assert_true(col_ci > 0)
-  checkmate::assert_character(col)
-  if (!is.null(col_symbol_size)) {
-    checkmate::assert_true(col_symbol_size > 0)
-  }
-
-  x_e <- vapply(seq_len(nr), function(i) {
-    # If a label row is selected NULL is returned with a warning (suppressed)
-    xi <- suppressWarnings(as.vector(tbl[i, col_x, drop = TRUE]))
-
-    if (!is.null(xi) && !(length(xi) <= 0) && is.numeric(xi)) {
-      xi
-    } else {
-      NA_real_
-    }
-  }, numeric(1))
-
-  x_ci <- lapply(seq_len(nr), function(i) {
-    xi <- suppressWarnings(as.vector(tbl[i, col_ci, drop = TRUE])) # as above
-
-    if (!is.null(xi) && !(length(xi) <= 0) && is.numeric(xi)) {
-      if (length(xi) != 2) {
-        stop("ci column needs two elements")
-      }
-      xi
-    } else {
-      c(NA_real_, NA_real_)
-    }
-  })
-
-  lower <- vapply(x_ci, `[`, numeric(1), 1)
-  upper <- vapply(x_ci, `[`, numeric(1), 2)
-
-  symbol_size <- if (!is.null(col_symbol_size)) {
-    tmp_symbol_size <- vapply(seq_len(nr), function(i) {
-      suppressWarnings(xi <- as.vector(tbl[i, col_symbol_size, drop = TRUE]))
-
-      if (!is.null(xi) && !(length(xi) <= 0) && is.numeric(xi)) {
-        xi
-      } else {
-        NA_real_
-      }
-    }, numeric(1))
-
-    # Scale symbol size.
-    tmp_symbol_size <- sqrt(tmp_symbol_size)
-    max_size <- max(tmp_symbol_size, na.rm = TRUE)
-    # Biggest points have radius is 2 * (1/3.5) lines not to overlap.
-    # See forest_dot_line.
-    2 * tmp_symbol_size / max_size
+  # Generate and modify table as ggplot object
+  gg_table <- rtable2gg(tbl, fontsize = font_size, colwidths = width_columns, lbl_col_padding = lbl_col_padding) +
+    theme(plot.margin = margin(0, 0, 0, 0.025, "npc"))
+  gg_table$scales$scales[[1]]$expand <- c(0.01, 0.01)
+  gg_table$scales$scales[[2]]$limits[2] <- nrow(mat_strings) + 1
+  if (nlines_hdr == 2) {
+    gg_table$scales$scales[[2]]$expand <- c(0, 0)
+    arms <- unique(mat_strings[1, ][nzchar(trimws(mat_strings[1, ]))])
   } else {
-    NULL
+    arms <- NULL
   }
 
-  grob_forest <- forest_grob(
-    tbl,
-    x_e,
-    lower,
-    upper,
-    vline,
-    forest_header,
-    xlim,
-    logx,
-    x_at,
-    width_row_names,
-    width_columns,
-    width_forest,
-    symbol_size = symbol_size,
-    col = col,
-    gp = gp,
-    vp = grid::plotViewport(margins = rep(1, 4))
-  )
+  tbl_df <- as_result_df(tbl)
+  dat_cols <- seq(which(names(tbl_df) == "node_class") + 1, ncol(tbl_df))
+  tbl_df <- tbl_df[, c(which(names(tbl_df) == "row_num"), dat_cols)]
+  names(tbl_df) <- c("row_num", tbl_stats)
 
-  if (draw) {
-    if (newpage) grid::grid.newpage()
-    grid::grid.draw(grob_forest)
+  # Check table data columns
+  if (!is.null(col_ci)) {
+    ci_col <- col_ci + 1
+  } else {
+    tbl_df[["empty_ci"]] <- rep(list(c(NA_real_, NA_real_)), nrow(tbl_df))
+    ci_col <- which(names(tbl_df) == "empty_ci")
+  }
+  if (length(tbl_df[, ci_col][[1]]) != 2) stop("CI column must have two elements (lower and upper limits).")
+
+  if (!is.null(col_x)) {
+    x_col <- col_x + 1
+  } else {
+    tbl_df[["empty_x"]] <- NA_real_
+    x_col <- which(names(tbl_df) == "empty_x")
+  }
+  if (!is.null(col_symbol_size)) {
+    sym_size <- unlist(tbl_df[, col_symbol_size + 1])
+  } else {
+    sym_size <- rep(1, nrow(tbl_df))
   }
 
-  invisible(grob_forest)
+  tbl_df[, c("ci_lwr", "ci_upr")] <- t(sapply(tbl_df[, ci_col], unlist))
+  x <- unlist(tbl_df[, x_col])
+  lwr <- unlist(tbl_df[["ci_lwr"]])
+  upr <- unlist(tbl_df[["ci_upr"]])
+  row_num <- nrow(mat_strings) - tbl_df[["row_num"]] - as.numeric(nlines_hdr == 2)
+
+  if (is.null(col)) col <- "#343cff"
+  if (length(col) == 1) col <- rep(col, nrow(tbl_df))
+  if (is.null(x_at)) x_at <- union(xlim, vline)
+  x_labels <- x_at
+
+  # Apply log transformation
+  if (logx) {
+    x_t <- log(x)
+    lwr_t <- log(lwr)
+    upr_t <- log(upr)
+    xlim_t <- log(xlim)
+  } else {
+    x_t <- x
+    lwr_t <- lwr
+    upr_t <- upr
+    xlim_t <- xlim
+  }
+
+  # Set up plot area
+  gg_plt <- ggplot(data = tbl_df) +
+    theme(
+      panel.background = element_rect(fill = "transparent", color = NA_character_),
+      plot.background = element_rect(fill = "transparent", color = NA_character_),
+      panel.grid.major = element_blank(),
+      panel.grid.minor = element_blank(),
+      axis.title.x = element_blank(),
+      axis.title.y = element_blank(),
+      axis.line.x = element_line(),
+      axis.text = element_text(size = font_size),
+      legend.position = "none",
+      plot.margin = margin(0, 0.1, 0.05, 0, "npc")
+    ) +
+    scale_x_continuous(
+      transform = ifelse(logx, "log", "identity"),
+      limits = xlim,
+      breaks = x_at,
+      labels = x_labels,
+      expand = c(0.01, 0)
+    ) +
+    scale_y_continuous(
+      limits = c(0, nrow(mat_strings) + 1),
+      breaks = NULL,
+      expand = c(0, 0)
+    ) +
+    coord_cartesian(clip = "off")
+
+  if (is.null(ggtheme)) {
+    gg_plt <- gg_plt + annotate(
+      "rect",
+      xmin = xlim[1],
+      xmax = xlim[2],
+      ymin = 0,
+      ymax = nrows_body + 0.5,
+      fill = "grey92"
+    )
+  }
+
+  if (!is.null(vline)) {
+    # Set default forest header
+    if (is.null(forest_header)) {
+      forest_header <- c(
+        paste(if (length(arms) == 2) arms[1] else "Comparison", "Better", sep = "\n"),
+        paste(if (length(arms) == 2) arms[2] else "Treatment", "Better", sep = "\n")
+      )
+    }
+
+    # Add vline and forest header labels
+    mid_pts <- if (logx) {
+      c(exp(mean(log(c(xlim[1], vline)))), exp(mean(log(c(vline, xlim[2])))))
+    } else {
+      c(mean(c(xlim[1], vline)), mean(c(vline, xlim[2])))
+    }
+    gg_plt <- gg_plt +
+      annotate(
+        "segment",
+        x = vline, xend = vline, y = 0, yend = nrows_body + 0.5
+      ) +
+      annotate(
+        "text",
+        x = mid_pts[1], y = nrows_body + 1.25,
+        label = forest_header[1],
+        size = font_size / .pt,
+        lineheight = 0.9
+      ) +
+      annotate(
+        "text",
+        x = mid_pts[2], y = nrows_body + 1.25,
+        label = forest_header[2],
+        size = font_size / .pt,
+        lineheight = 0.9
+      )
+  }
+
+  # Add points to plot
+  if (any(!is.na(x_t))) {
+    x_t[x < xlim[1] | x > xlim[2]] <- NA
+    gg_plt <- gg_plt + geom_point(
+      x = x_t,
+      y = row_num,
+      color = col,
+      aes(size = sym_size),
+      na.rm = TRUE
+    )
+  }
+
+  for (i in seq_len(nrow(tbl_df))) {
+    # Determine which arrow(s) to add to CI lines
+    which_arrow <- c(lwr_t[i] < xlim_t[1], upr_t[i] > xlim_t[2])
+    which_arrow <- dplyr::case_when(
+      all(which_arrow) ~ "both",
+      which_arrow[1] ~ "first",
+      which_arrow[2] ~ "last",
+      TRUE ~ NA_character_
+    )
+
+    # Add CI lines
+    gg_plt <- gg_plt +
+      if (!is.na(which_arrow)) {
+        annotate(
+          "segment",
+          x = if (!which_arrow %in% c("first", "both")) lwr[i] else xlim[1],
+          xend = if (!which_arrow %in% c("last", "both")) upr[i] else xlim[2],
+          y = row_num[i], yend = row_num[i],
+          color = if (length(col) == 1) col else col[i],
+          arrow = arrow(length = unit(0.05, "npc"), ends = which_arrow),
+          na.rm = TRUE
+        )
+      } else {
+        annotate(
+          "segment",
+          x = lwr[i], xend = upr[i],
+          y = row_num[i], yend = row_num[i],
+          color = if (length(col) == 1) col else col[i],
+          na.rm = TRUE
+        )
+      }
+  }
+
+  # Apply custom ggtheme to plot
+  if (!is.null(ggtheme)) gg_plt <- gg_plt + ggtheme
+
+  if (as_list) {
+    list(
+      table = gg_table,
+      plot = gg_plt
+    )
+  } else {
+    cowplot::plot_grid(
+      gg_table,
+      gg_plt,
+      align = "h",
+      axis = "tblr",
+      rel_widths = c(1 - rel_width_forest, rel_width_forest)
+    )
+  }
 }
 
-#' Forest Plot Grob
+#' Forest plot grob
+#'
+#' @description `r lifecycle::badge("deprecated")`
 #'
 #' @inheritParams g_forest
-#' @param tbl ([rtables::rtable()])
+#' @param tbl (`VTableTree`)\cr `rtables` table object.
 #' @param x (`numeric`)\cr coordinate of point.
 #' @param lower,upper (`numeric`)\cr lower/upper bound of the confidence interval.
 #' @param symbol_size (`numeric`)\cr vector with relative size for plot symbol.
-#' If `NULL`, the same symbol size is used.
+#'   If `NULL`, the same symbol size is used.
 #'
 #' @details
 #' The heights get automatically determined.
 #'
-#' @noRd
-#'
 #' @examples
 #' tbl <- rtable(
 #'   header = rheader(
@@ -297,6 +472,9 @@ g_forest <- function(tbl,
 #'
 #' draw_grob(p)
 #' }
+#'
+#' @noRd
+#' @keywords internal
 forest_grob <- function(tbl,
                         x,
                         lower,
@@ -314,6 +492,11 @@ forest_grob <- function(tbl,
                         name = NULL,
                         gp = NULL,
                         vp = NULL) {
+  lifecycle::deprecate_warn(
+    "0.9.4", "forest_grob()",
+    details = "`g_forest` now generates `ggplot` objects. This function is no longer used within `tern`."
+  )
+
   nr <- nrow(tbl)
   if (is.null(vline)) {
     checkmate::assert_true(is.null(forest_header))
@@ -423,7 +606,7 @@ forest_grob <- function(tbl,
             grid::gTree(
               children = grid::gList(
                 # this may overflow, to fix, look here
-                # https://stackoverflow.com/questions/33623169/add-multi-line-footnote-to-tablegrob-while-using-gridextra-in-r #nolintr
+                # https://stackoverflow.com/questions/33623169/add-multi-line-footnote-to-tablegrob-while-using-gridextra-in-r # nolint
                 grid::textGrob(
                   forest_header[1],
                   x = grid::unit(vline, "native") - grid::unit(1, "lines"),
@@ -497,7 +680,6 @@ forest_grob <- function(tbl,
   )
 }
 
-
 cell_in_rows <- function(row_name,
                          cells,
                          cell_spans,
@@ -582,11 +764,14 @@ cell_in_rows <- function(row_name,
   )
 }
 
-#' Graphic Object: Forest Dot Line
+#' Graphic object: forest dot line
+#'
+#' @description `r lifecycle::badge("deprecated")`
 #'
 #' Calculate the `grob` corresponding to the dot line within the forest plot.
 #'
 #' @noRd
+#' @keywords internal
 forest_dot_line <- function(x,
                             lower,
                             upper,
@@ -595,6 +780,11 @@ forest_dot_line <- function(x,
                             symbol_size = 1,
                             col = "blue",
                             datavp) {
+  lifecycle::deprecate_warn(
+    "0.9.4", "forest_dot_line()",
+    details = "`g_forest` now generates `ggplot` objects. This function is no longer used within `tern`."
+  )
+
   ci <- c(lower, upper)
   if (any(!is.na(c(x, ci)))) {
     # line
@@ -661,14 +851,18 @@ forest_dot_line <- function(x,
   }
 }
 
-#' Create a Viewport Tree for the Forest Plot
-#' @param tbl (`rtable`)
-#' @param width_row_names (`grid::unit`)\cr Width of row names
-#' @param width_columns (`grid::unit`)\cr Width of column spans
-#' @param width_forest (`grid::unit`)\cr Width of the forest plot
-#' @param gap_column (`grid::unit`)\cr Gap width between the columns
-#' @param gap_header (`grid::unit`)\cr Gap width between the header
-#' @param mat_form matrix print form of the table
+#' Create a viewport tree for the forest plot
+#'
+#' @description `r lifecycle::badge("deprecated")`
+#'
+#' @param tbl (`VTableTree`)\cr `rtables` table object.
+#' @param width_row_names (`grid::unit`)\cr width of row names.
+#' @param width_columns (`grid::unit`)\cr width of column spans.
+#' @param width_forest (`grid::unit`)\cr width of the forest plot.
+#' @param gap_column (`grid::unit`)\cr gap width between the columns.
+#' @param gap_header (`grid::unit`)\cr gap width between the header.
+#' @param mat_form (`MatrixPrintForm`)\cr matrix print form of the table.
+#'
 #' @return A viewport tree.
 #'
 #' @examples
@@ -699,6 +893,12 @@ forest_viewport <- function(tbl,
                             gap_column = grid::unit(1, "lines"),
                             gap_header = grid::unit(1, "lines"),
                             mat_form = NULL) {
+  lifecycle::deprecate_warn(
+    "0.9.4",
+    "forest_viewport()",
+    details = "`g_forest` now generates `ggplot` objects. This function is no longer used within `tern`."
+  )
+
   checkmate::assert_class(tbl, "VTableTree")
   checkmate::assert_true(grid::is.unit(width_forest))
   if (!is.null(width_row_names)) {
@@ -770,11 +970,14 @@ forest_viewport <- function(tbl,
   vp_tbl
 }
 
-#' Viewport Forest Plot: Table Part
+#' Viewport forest plot: table part
+#'
+#' @description `r lifecycle::badge("deprecated")`
 #'
 #' Prepares a viewport for the table included in the forest plot.
 #'
 #' @noRd
+#' @keywords internal
 vp_forest_table_part <- function(nrow,
                                  ncol,
                                  l_row,
@@ -782,6 +985,11 @@ vp_forest_table_part <- function(nrow,
                                  widths,
                                  heights,
                                  name) {
+  lifecycle::deprecate_warn(
+    "0.9.4", "vp_forest_table_part()",
+    details = "`g_forest` now generates `ggplot` objects. This function is no longer used within `tern`."
+  )
+
   grid::vpTree(
     grid::viewport(
       name = name,
@@ -823,11 +1031,19 @@ vp_forest_table_part <- function(nrow,
   )
 }
 
-#' Forest Rendering
+#' Forest rendering
+#'
+#' @description `r lifecycle::badge("deprecated")`
 #'
 #' Renders the forest grob.
 #'
 #' @noRd
+#' @keywords internal
 grid.forest <- function(...) { # nolint
+  lifecycle::deprecate_warn(
+    "0.9.4", "grid.forest()",
+    details = "`g_forest` now generates `ggplot` objects. This function is no longer used within `tern`."
+  )
+
   grid::grid.draw(forest_grob(...))
 }
