@@ -1,4 +1,4 @@
-#' Helper Functions for Tabulating Biomarker Effects on Survival by Subgroup
+#' Helper functions for tabulating biomarker effects on survival by subgroup
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
@@ -30,7 +30,7 @@
 #' @name h_survival_biomarkers_subgroups
 NULL
 
-#' @describeIn h_survival_biomarkers_subgroups helps with converting the "survival" function variable list
+#' @describeIn h_survival_biomarkers_subgroups Helps with converting the "survival" function variable list
 #'   to the "Cox regression" variable list. The reason is that currently there is an inconsistency between the variable
 #'   names accepted by `extract_survival_subgroups()` and `fit_coxreg_multivar()`.
 #'
@@ -67,11 +67,11 @@ h_surv_to_coxreg_variables <- function(variables, biomarker) {
   )
 }
 
-#' @describeIn h_survival_biomarkers_subgroups prepares estimates for number of events, patients and median survival
+#' @describeIn h_survival_biomarkers_subgroups Prepares estimates for number of events, patients and median survival
 #'   times, as well as hazard ratio estimates, confidence intervals and p-values, for multiple biomarkers
 #'   in a given single data set.
 #'   `variables` corresponds to names of variables found in `data`, passed as a named list and requires elements
-#'   `tte`, `is_event`, `biomarkers` (vector of continuous biomarker variables) and optionally `subgroups` and `strat`.
+#'   `tte`, `is_event`, `biomarkers` (vector of continuous biomarker variables) and optionally `subgroups` and `strata`.
 #'
 #' @return
 #' * `h_coxreg_mult_cont_df()` returns a `data.frame` containing estimates and statistics for the selected biomarkers.
@@ -107,6 +107,15 @@ h_surv_to_coxreg_variables <- function(variables, biomarker) {
 h_coxreg_mult_cont_df <- function(variables,
                                   data,
                                   control = control_coxreg()) {
+  if ("strat" %in% names(variables)) {
+    warning(
+      "Warning: the `strat` element name of the `variables` list argument to `h_coxreg_mult_cont_df() ",
+      "was deprecated in tern 0.9.3.\n  ",
+      "Please use the name `strata` instead of `strat` in the `variables` argument."
+    )
+    variables[["strata"]] <- variables[["strat"]]
+  }
+
   assert_df_with_variables(data, variables)
   checkmate::assert_list(control, names = "named")
   checkmate::assert_character(variables$biomarkers, min.len = 1, any.missing = FALSE)
@@ -169,7 +178,7 @@ h_coxreg_mult_cont_df <- function(variables,
   }
 }
 
-#' @describeIn h_survival_biomarkers_subgroups prepares a single sub-table given a `df_sub` containing
+#' @describeIn h_survival_biomarkers_subgroups Prepares a single sub-table given a `df_sub` containing
 #'   the results for a single biomarker.
 #'
 #' @param df (`data.frame`)\cr results for a single biomarker, as part of what is
