@@ -1,4 +1,4 @@
-#' Tabulate Biomarker Effects on Binary Response by Subgroup
+#' Tabulate biomarker effects on binary response by subgroup
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
@@ -101,7 +101,7 @@ tabulate_rsp_biomarkers <- function(df,
   )
 }
 
-#' Prepares Response Data Estimates for Multiple Biomarkers in a Single Data Frame
+#' Prepare response data estimates for multiple biomarkers in a single data frame
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
@@ -110,7 +110,7 @@ tabulate_rsp_biomarkers <- function(df,
 #' for multiple biomarkers across population subgroups in a single data frame.
 #' `variables` corresponds to the names of variables found in `data`, passed as a
 #' named list and requires elements `rsp` and `biomarkers` (vector of continuous
-#' biomarker variables) and optionally `covariates`, `subgroups` and `strat`.
+#' biomarker variables) and optionally `covariates`, `subgroups` and `strata`.
 #' `groups_lists` optionally specifies groupings for `subgroups` variables.
 #'
 #' @inheritParams argument_convention
@@ -156,14 +156,14 @@ tabulate_rsp_biomarkers <- function(df,
 #' # Here we group the levels of `BMRKR2` manually, and we add a stratification
 #' # variable `STRATA1`. We also here use a continuous variable `EOSDY`
 #' # which is then binarized internally (response is defined as this variable
-#' # being larger than 500).
+#' # being larger than 750).
 #' df_grouped <- extract_rsp_biomarkers(
 #'   variables = list(
 #'     rsp = "EOSDY",
 #'     biomarkers = c("BMRKR1", "AGE"),
 #'     covariates = "SEX",
 #'     subgroups = "BMRKR2",
-#'     strat = "STRATA1"
+#'     strata = "STRATA1"
 #'   ),
 #'   data = adrs_f,
 #'   groups_lists = list(
@@ -174,7 +174,7 @@ tabulate_rsp_biomarkers <- function(df,
 #'     )
 #'   ),
 #'   control = control_logistic(
-#'     response_definition = "I(response > 500)"
+#'     response_definition = "I(response > 750)"
 #'   )
 #' )
 #' df_grouped
@@ -185,6 +185,15 @@ extract_rsp_biomarkers <- function(variables,
                                    groups_lists = list(),
                                    control = control_logistic(),
                                    label_all = "All Patients") {
+  if ("strat" %in% names(variables)) {
+    warning(
+      "Warning: the `strat` element name of the `variables` list argument to `extract_rsp_biomarkers() ",
+      "was deprecated in tern 0.9.3.\n  ",
+      "Please use the name `strata` instead of `strat` in the `variables` argument."
+    )
+    variables[["strata"]] <- variables[["strat"]]
+  }
+
   assert_list_of_variables(variables)
   checkmate::assert_string(variables$rsp)
   checkmate::assert_character(variables$subgroups, null.ok = TRUE)
