@@ -1,4 +1,4 @@
-#' Summarize Variables in Columns
+#' Summarize variables in columns
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
@@ -62,17 +62,11 @@
 #' @export
 summarize_colvars <- function(lyt,
                               ...,
-                              na_level = lifecycle::deprecated(),
                               na_str = default_na_str(),
                               .stats = c("n", "mean_sd", "median", "range", "count_fraction"),
                               .formats = NULL,
                               .labels = NULL,
                               .indent_mods = NULL) {
-  if (lifecycle::is_present(na_level)) {
-    lifecycle::deprecate_warn("0.9.1", "summarize_colvars(na_level)", "summarize_colvars(na_str)")
-    na_str <- na_level
-  }
-
   extra_args <- list(.stats = .stats, na_str = na_str, ...)
   if (!is.null(.formats)) extra_args[[".formats"]] <- .formats
   if (!is.null(.labels)) extra_args[[".labels"]] <- .labels
