@@ -123,7 +123,7 @@ get_stats <- function(method_groups = "analyze_vars_numeric", stats_in = NULL, a
 
 #' @describeIn default_stats_formats_labels Get formats corresponding to a list of statistics.
 #'
-#' @param formats_in (named `vector`) \cr inserted formats to replace defaults. It can be a
+#' @param formats_in (named `vector`)\cr inserted formats to replace defaults. It can be a
 #'   character vector from [formatters::list_valid_format_labels()] or a custom format function.
 #'
 #' @return
@@ -179,7 +179,7 @@ get_formats_from_stats <- function(stats, formats_in = NULL) {
 
 #' @describeIn default_stats_formats_labels Get labels corresponding to a list of statistics.
 #'
-#' @param labels_in (named `vector` of `character`)\cr inserted labels to replace defaults.
+#' @param labels_in (named `character`)\cr inserted labels to replace defaults.
 #' @param row_nms (`character`)\cr row names. Levels of a `factor` or `character` variable, each
 #'   of which the statistics in `.stats` will be calculated for. If this parameter is set, these
 #'   variable levels will be used as the defaults, and the names of the given custom values should
@@ -203,7 +203,7 @@ get_formats_from_stats <- function(stats, formats_in = NULL) {
 #'
 #' @export
 get_labels_from_stats <- function(stats, labels_in = NULL, row_nms = NULL) {
-  checkmate::assert_character(stats, min.len = 1)
+  checkmate::assert_character(stats, min.len = 1, null.ok = TRUE)
   checkmate::assert_character(row_nms, null.ok = TRUE)
   # It may be a list
   if (checkmate::test_list(labels_in, null.ok = TRUE)) {
@@ -296,7 +296,7 @@ get_indents_from_stats <- function(stats, indents_in = NULL, row_nms = NULL) {
   out
 }
 
-#' Update Labels According to Control Specifications
+#' Update labels according to control specifications
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
@@ -305,10 +305,10 @@ get_indents_from_stats <- function(stats, indents_in = NULL, row_nms = NULL) {
 #' label for statistic `mean_ci` will be updated to `"Mean 90% CI"`. Any labels that are supplied
 #' via `labels_custom` will not be updated regardless of `control`.
 #'
-#' @param labels_default (named `vector` of `character`)\cr a named vector of statistic labels to modify
+#' @param labels_default (named `character`)\cr a named vector of statistic labels to modify
 #'   according to the control specifications. Labels that are explicitly defined in `labels_custom` will
 #'   not be affected.
-#' @param labels_custom (named `vector` of `character`)\cr named vector of labels that are customized by
+#' @param labels_custom (named `character`)\cr named vector of labels that are customized by
 #'   the user and should not be affected by `control`.
 #' @param control (named `list`)\cr list of control parameters to apply to adjust default labels.
 #'
@@ -423,7 +423,7 @@ tern_default_formats <- c(
   mean_ci = "(xx.xx, xx.xx)",
   mean_sei = "(xx.xx, xx.xx)",
   mean_sdi = "(xx.xx, xx.xx)",
-  mean_pval = "xx.xx",
+  mean_pval = "x.xxxx | (<0.0001)",
   median = "xx.x",
   mad = "xx.x",
   median_ci = "(xx.xx, xx.xx)",
@@ -491,7 +491,7 @@ tern_default_labels <- c(
 #' @describeIn default_stats_formats_labels Quick function to retrieve default formats for summary statistics:
 #'   [analyze_vars()] and [analyze_vars_in_cols()] principally.
 #'
-#' @param type (`flag`)\cr is it going to be `"numeric"` or `"counts"`?
+#' @param type (`string`)\cr `"numeric"` or `"counts"`.
 #'
 #' @return
 #' * `summary_formats()` returns a named `vector` of default statistic formats for the given data type.
@@ -507,9 +507,10 @@ summary_formats <- function(type = "numeric", include_pval = FALSE) {
 }
 
 #' @describeIn default_stats_formats_labels Quick function to retrieve default labels for summary statistics.
-#'   Returns labels of descriptive statistics which are understood by `rtables`. Similar to `summary_formats`
+#'   Returns labels of descriptive statistics which are understood by `rtables`. Similar to `summary_formats`.
+#'
+#' @param include_pval (`flag`)\cr same as the `add_pval` argument in [get_stats()].
 #'
-#' @param include_pval (`flag`)\cr deprecated parameter. Same as `add_pval`.
 #' @return
 #' * `summary_labels` returns a named `vector` of default statistic labels for the given data type.
 #'
@@ -522,69 +523,3 @@ summary_labels <- function(type = "numeric", include_pval = FALSE) {
   met_grp <- paste0(c("analyze_vars", type), collapse = "_")
   get_labels_from_stats(get_stats(met_grp, add_pval = include_pval))
 }
-
-#' @describeIn default_stats_formats_labels `r lifecycle::badge("deprecated")` Function to
-#'   configure settings for default or custom summary statistics for a given data type. In
-#'   addition to selecting a custom subset of statistics, the user can also set custom
-#'   formats, labels, and indent modifiers for any of these statistics.
-#'
-#' @param stats_custom (`named vector` of `character`)\cr vector of statistics to include if
-#'   not the defaults. This argument overrides `include_pval` and other custom value arguments
-#'   such that only settings for these statistics will be returned.
-#' @param formats_custom (`named vector` of `character`)\cr vector of custom statistics formats
-#'   to use in place of the defaults defined in [`summary_formats()`]. Names should be a subset
-#'   of the statistics defined in `stats_custom` (or default statistics if this is `NULL`).
-#' @param labels_custom (`named vector` of `character`)\cr vector of custom statistics labels
-#'   to use in place of the defaults defined in [`summary_labels()`]. Names should be a subset
-#'   of the statistics defined in `stats_custom` (or default statistics if this is `NULL`).
-#' @param indent_mods_custom (`integer` or `named vector` of `integer`)\cr vector of custom
-#'   indentation modifiers for statistics to use instead of the default of `0L` for all statistics.
-#'   Names should be a subset of the statistics defined in `stats_custom` (or default statistics
-#'   if this is `NULL`). Alternatively, the same indentation modifier can be applied to all
-#'   statistics by setting `indent_mods_custom` to a single integer value.
-#'
-#' @return
-#' * `summary_custom` returns a `list` of 4 named elements: `stats`, `formats`, `labels`,
-#'   and `indent_mods`.
-#'
-#' @examples
-#' summary_custom()
-#' summary_custom(type = "counts", include_pval = TRUE)
-#' summary_custom(
-#'   include_pval = TRUE, stats_custom = c("n", "mean", "sd", "pval"),
-#'   labels_custom = c(sd = "Std. Dev."), indent_mods_custom = 3L
-#' )
-#'
-#' @export
-summary_custom <- function(type = "numeric",
-                           include_pval = FALSE,
-                           stats_custom = NULL,
-                           formats_custom = NULL,
-                           labels_custom = NULL,
-                           indent_mods_custom = NULL) {
-  lifecycle::deprecate_warn(
-    "0.9.0.9001",
-    "summary_custom()",
-    details = "Please use `get_stats`, `get_formats_from_stats`, and `get_labels_from_stats` directly instead."
-  )
-  met_grp <- paste0(c("analyze_vars", type), collapse = "_")
-  .stats <- get_stats(met_grp, stats_custom, add_pval = include_pval)
-  .formats <- get_formats_from_stats(.stats, formats_custom)
-  .labels <- get_labels_from_stats(.stats, labels_custom)
-  .indent_mods <- stats::setNames(rep(0L, length(.stats)), .stats)
-
-  if (!is.null(indent_mods_custom)) {
-    if (is.null(names(indent_mods_custom)) && length(indent_mods_custom) == 1) {
-      .indent_mods[names(.indent_mods)] <- indent_mods_custom
-    } else {
-      .indent_mods[names(indent_mods_custom)] <- indent_mods_custom
-    }
-  }
-
-  list(
-    stats = .stats,
-    formats = .formats,
-    labels = .labels,
-    indent_mods = .indent_mods[.stats]
-  )
-}
